﻿using System;
using System.IO;

namespace EmbededPython
{
    public class EventRaisingStreamWriter : StreamWriter
    {
        #region Event
        public event EventHandler<EvtArgs<string>> StringWritten;
        #endregion

        #region CTOR
        public EventRaisingStreamWriter(Stream s)
            : base(s)
        { }
        #endregion

        #region Private Methods
        private void LaunchEvent(string txtWritten)
        {
            if (StringWritten != null)
            {
                StringWritten(this, new EvtArgs<string>(txtWritten));
            }
        }
        #endregion

        #region Overrides

        public override void Write(string value)
        {
            base.Write(value);
            LaunchEvent(value);
        }
        public override void Write(bool value)
        {
            base.Write(value);
            LaunchEvent(value.ToString());
        }

        #endregion
    }
    public class EvtArgs<T> : EventArgs
    {
        public T Value
        {
            get;
            private set;
        }
        public EvtArgs(T value)
        {
            this.Value = value;
        }
    }
}